@@ -4,39 +4,41 @@ __license__ = 'MIT'
 __copyright__ = 'Copyright 2021-present yupix'
 __author_email__ = 'yupi0982@outlook.jp'
 __url__ = 'https://github.com/yupix/Mi.py'
-__version__ = '0.1.0'
+__version__ = '0.2.5'
 
 __path__ = __import__('pkgutil').extend_path(__path__, __name__)
 
-from .ext import task
-from .ext.task import Loop, loop
-from .note import Message, Header, Note, Reaction, ReactionNote, User, Instance
+from .instance import Instance
+from .emoji import Emoji
+from .user import UserProfile
+from .chart import Chart, Local, Remote
+from .drive import Drive, Properties
+from .note import Follow, Header, Note, Reaction
 from .router import Router
-from .utils import bool_to_string
-from .drive import Properties, Drive
-from .bot import Bot, BotBase
+from .client import Client, BotBase
+from .ext import *
 
 __all__ = [
-    'bot',
+    'Chart',
+    'Local',
+    'Remote',
+    'Emoji',
+    'Follow',
+    'client',
+    'BotBase',
     'http',
     'note',
     'router',
     'ext',
-    'task',
-    'Loop',
-    'loop',
     'utils',
     'drive',
     'Note',
-    'ReactionNote',
-    'Instance',
-    'bool_to_string',
-    'Message',
-    'Header',
-    'User',
     'Reaction',
-    'Bot',
+    'UserProfile',
+    'Instance',
+    'Header',
+    'Client',
     'Router',
     'Drive',
-    'Properties'
+    'Properties',
 ]
